@@ -11,8 +11,7 @@
 #include <algorithm>
 #include <iostream>
 #include <sstream>
-#include <boost/shared_ptr.hpp>
-#include <boost/make_shared.hpp>
+#include <memory>
 
 
 // TODO: Streaming response body (with chunked transfer encoding)
@@ -26,12 +25,12 @@ void on_request(uv_stream_t* handle, int status) {
   }
 
   // Copy the shared_ptr
-  boost::shared_ptr<Socket> pSocket(*(boost::shared_ptr<Socket>*)handle->data);
+  std::shared_ptr<Socket> pSocket(*(std::shared_ptr<Socket>*)handle->data);
   CallbackQueue* bg_queue = pSocket->background_queue;
 
   // Freed by HttpRequest itself when close() is called, which
   // can occur on EOF, error, or when the Socket is destroyed
-  boost::shared_ptr<HttpRequest> req = createHttpRequest(
+  std::shared_ptr<HttpRequest> req = createHttpRequest(
     handle->loop, pSocket->pWebApplication, pSocket, bg_queue
   );
 
@@ -45,17 +44,21 @@ void on_request(uv_stream_t* handle, int status) {
 
 }
 
-uv_stream_t* createPipeServer(uv_loop_t* pLoop, const std::string& name,
-  int mask, boost::shared_ptr<WebApplication> pWebApplication,
-  CallbackQueue* background_queue)
-{
+uv_stream_t* createPipeServer(
+  uv_loop_t* pLoop,
+  const std::string& name,
+  int mask,
+  std::shared_ptr<WebApplication> pWebApplication,
+  bool quiet,
+  CallbackQueue* background_queue
+) {
   ASSERT_BACKGROUND_THREAD()
 
   // We own pWebApplication. It will be destroyed by the socket but if in
   // the future we have failure cases that stop execution before we get
   // that far, we MUST delete pWebApplication ourselves.
 
-  boost::shared_ptr<Socket> pSocket = boost::make_shared<Socket>(
+  std::shared_ptr<Socket> pSocket = std::make_shared<Socket>(
     pWebApplication, background_queue
   );
 
@@ -64,7 +67,7 @@ uv_stream_t* createPipeServer(uv_loop_t* pLoop, const std::string& name,
   pSocket->handle.isTcp = false;
   // data is a pointer to the shared_ptr. This is necessary because the
   // uv_stream_t.data field is a void*.
-  pSocket->handle.stream.data = new boost::shared_ptr<Socket>(pSocket);
+  pSocket->handle.stream.data = new std::shared_ptr<Socket>(pSocket);
 
   mode_t oldMask = 0;
   if (mask >= 0)
@@ -74,14 +77,16 @@ uv_stream_t* createPipeServer(uv_loop_t* pLoop, const std::string& name,
     umask(oldMask);
 
   if (r) {
-    err_printf("createPipeServer: %s\n", uv_strerror(r));
+    if (!quiet)
+      err_printf("createPipeServer: %s\n", uv_strerror(r));
     // It's important that close() is explicitly called, so that the uv_pipe_t is cleaned up
     pSocket->close();
     return NULL;
   }
   r = uv_listen((uv_stream_t*)&pSocket->handle.stream, 128, &on_request);
   if (r) {
-    err_printf("createPipeServer: %s\n", uv_strerror(r));
+    if (!quiet)
+      err_printf("createPipeServer: %s\n", uv_strerror(r));
     // It's important that close() is explicitly called, so that the uv_pipe_t is cleaned up
     pSocket->close();
     return NULL;
@@ -92,30 +97,39 @@ uv_stream_t* createPipeServer(uv_loop_t* pLoop, const std::string& name,
 
 // A wrapper for createPipeServer. The main thread schedules this to run on
 // the background thread, then waits for this to finish, using a barrier.
-void createPipeServerSync(uv_loop_t* loop, const std::string& name,
-  int mask, boost::shared_ptr<WebApplication> pWebApplication,
+void createPipeServerSync(
+  uv_loop_t* loop,
+  const std::string& name,
+  int mask,
+  std::shared_ptr<WebApplication> pWebApplication,
+  bool quiet,
   CallbackQueue* background_queue,
-  uv_stream_t** pServer, boost::shared_ptr<Barrier> blocker)
-{
+  uv_stream_t** pServer,
+  std::shared_ptr<Barrier> blocker
+) {
   ASSERT_BACKGROUND_THREAD()
 
-  *pServer = createPipeServer(loop, name, mask, pWebApplication, background_queue);
+  *pServer = createPipeServer(loop, name, mask, pWebApplication, quiet, background_queue);
 
   // Tell the main thread that the server is ready
   blocker->wait();
 }
 
-uv_stream_t* createTcpServer(uv_loop_t* pLoop, const std::string& host,
-  int port, boost::shared_ptr<WebApplication> pWebApplication,
-  CallbackQueue* background_queue)
-{
+uv_stream_t* createTcpServer(
+  uv_loop_t* pLoop,
+  const std::string& host,
+  int port,
+  std::shared_ptr<WebApplication> pWebApplication,
+  bool quiet,
+  CallbackQueue* background_queue
+) {
   ASSERT_BACKGROUND_THREAD()
 
   // We own pWebApplication. It will be destroyed by the socket but if in
   // the future we have failure cases that stop execution before we get
   // that far, we MUST delete pWebApplication ourselves.
 
-  boost::shared_ptr<Socket> pSocket = boost::make_shared<Socket>(
+  std::shared_ptr<Socket> pSocket = std::make_shared<Socket>(
     pWebApplication, background_queue
   );
 
@@ -124,7 +138,7 @@ uv_stream_t* createTcpServer(uv_loop_t* pLoop, const std::string& host,
   pSocket->handle.isTcp = true;
   // data is a pointer to the shared_ptr. This is necessary because the
   // uv_stream_t.data field is a void*.
-  pSocket->handle.stream.data = new boost::shared_ptr<Socket>(pSocket);
+  pSocket->handle.stream.data = new std::shared_ptr<Socket>(pSocket);
 
   int r;
   // Lifetime of these needs to encompass use of pAddress in uv_tcp_bind()
@@ -140,11 +154,13 @@ uv_stream_t* createTcpServer(uv_loop_t* pLoop, const std::string& host,
     pAddress = reinterpret_cast<sockaddr*>(&addr4);
   } else {
     r = 1;
-    err_printf("%s is not a valid IPv4 or IPv6 address.\n", host.c_str());
+    if (!quiet)
+      err_printf("%s is not a valid IPv4 or IPv6 address.\n", host.c_str());
   }
 
   if (r) {
-    err_printf("createTcpServer: %s\n", uv_strerror(r));
+    if (!quiet)
+      err_printf("createTcpServer: %s\n", uv_strerror(r));
     // It's important that close() is explicitly called, so that the uv_tcp_t is cleaned up
     pSocket->close();
     return NULL;
@@ -153,14 +169,16 @@ uv_stream_t* createTcpServer(uv_loop_t* pLoop, const std::string& host,
   r = uv_tcp_bind(&pSocket->handle.tcp, pAddress, 0);
 
   if (r) {
-    err_printf("createTcpServer: %s\n", uv_strerror(r));
+    if (!quiet)
+      err_printf("createTcpServer: %s\n", uv_strerror(r));
     // It's important that close() is explicitly called, so that the uv_tcp_t is cleaned up
     pSocket->close();
     return NULL;
   }
   r = uv_listen((uv_stream_t*)&pSocket->handle.stream, 128, &on_request);
   if (r) {
-    err_printf("createTcpServer: %s\n", uv_strerror(r));
+    if (!quiet)
+      err_printf("createTcpServer: %s\n", uv_strerror(r));
     // It's important that close() is explicitly called, so that the uv_tcp_t is cleaned up
     pSocket->close();
     return NULL;
@@ -171,14 +189,19 @@ uv_stream_t* createTcpServer(uv_loop_t* pLoop, const std::string& host,
 
 // A wrapper for createTcpServer. The main thread schedules this to run on the
 // background thread, then waits for this to finish, using a barrier.
-void createTcpServerSync(uv_loop_t* pLoop, const std::string& host,
-  int port, boost::shared_ptr<WebApplication> pWebApplication,
+void createTcpServerSync(
+  uv_loop_t* pLoop,
+  const std::string& host,
+  int port,
+  std::shared_ptr<WebApplication> pWebApplication,
+  bool quiet,
   CallbackQueue* background_queue,
-  uv_stream_t** pServer, boost::shared_ptr<Barrier> blocker)
-{
+  uv_stream_t** pServer,
+  std::shared_ptr<Barrier> blocker
+) {
   ASSERT_BACKGROUND_THREAD()
 
-  *pServer = createTcpServer(pLoop, host, port, pWebApplication, background_queue);
+  *pServer = createTcpServer(pLoop, host, port, pWebApplication, quiet, background_queue);
 
   // Tell the main thread that the server is ready
   blocker->wait();
@@ -188,7 +211,7 @@ void createTcpServerSync(uv_loop_t* pLoop, const std::string& host,
 void freeServer(uv_stream_t* pHandle) {
   ASSERT_BACKGROUND_THREAD()
   // TODO: Check if server is still running?
-  boost::shared_ptr<Socket>* ppSocket = (boost::shared_ptr<Socket>*)pHandle->data;
+  std::shared_ptr<Socket>* ppSocket = (std::shared_ptr<Socket>*)pHandle->data;
   (*ppSocket)->close();
   // ppSocket gets deleted in a callback in close()
 }
