@@ -9,9 +9,9 @@
 void on_response_written(uv_write_t* handle, int status) {
   ASSERT_BACKGROUND_THREAD()
   // Make a local copy of the shared_ptr before deleting the original one.
-  boost::shared_ptr<HttpResponse> pResponse(*(boost::shared_ptr<HttpResponse>*)handle->data);
+  std::shared_ptr<HttpResponse> pResponse(*(std::shared_ptr<HttpResponse>*)handle->data);
 
-  delete (boost::shared_ptr<HttpResponse>*)handle->data;
+  delete (std::shared_ptr<HttpResponse>*)handle->data;
   free(handle);
 
   pResponse->onResponseWritten(status);
@@ -44,11 +44,11 @@ void HttpResponse::setHeader(const std::string& name, const std::string& value)
 }
 
 class HttpResponseExtendedWrite : public ExtendedWrite {
-  boost::shared_ptr<HttpResponse> _pParent;
+  std::shared_ptr<HttpResponse> _pParent;
 public:
-  HttpResponseExtendedWrite(boost::shared_ptr<HttpResponse> pParent,
+  HttpResponseExtendedWrite(std::shared_ptr<HttpResponse> pParent,
                             uv_stream_t* pHandle,
-                            boost::shared_ptr<DataSource> pDataSource) :
+                            std::shared_ptr<DataSource> pDataSource) :
       ExtendedWrite(pHandle, pDataSource), _pParent(pParent) {}
 
   void onWriteComplete(int status) {
@@ -58,7 +58,7 @@ public:
 
 void HttpResponse::writeResponse() {
   ASSERT_BACKGROUND_THREAD()
-  trace("HttpResponse::writeResponse");
+  debug_log("HttpResponse::writeResponse", LOG_DEBUG);
   // TODO: Optimize
   std::ostringstream response(std::ios_base::binary);
   response << "HTTP/1.1 " << _statusCode << " " << _status << "\r\n";
@@ -73,7 +73,11 @@ void HttpResponse::writeResponse() {
     }
   }
 
-  if (_pBody && !hasContentLengthHeader) {
+  // Some valid responses (such as HTTP 204 and 304) must not set this header,
+  // since they can't have a body.
+  //
+  // See: https://tools.ietf.org/html/rfc7230#section-3.3.2
+  if (_pBody != nullptr && !hasContentLengthHeader) {
     response << "Content-Length: " << _pBody->size() << "\r\n";
   }
 
@@ -99,13 +103,13 @@ void HttpResponse::writeResponse() {
   uv_write_t* pWriteReq = (uv_write_t*)malloc(sizeof(uv_write_t));
   memset(pWriteReq, 0, sizeof(uv_write_t));
   // Pointer to shared_ptr
-  pWriteReq->data = new boost::shared_ptr<HttpResponse>(shared_from_this());
+  pWriteReq->data = new std::shared_ptr<HttpResponse>(shared_from_this());
 
   int r = uv_write(pWriteReq, _pRequest->handle(), &headerBuf, 1,
       &on_response_written);
   if (r) {
-    _pRequest->fatal_error("uv_write", uv_strerror(r));
-    delete (boost::shared_ptr<HttpResponse>*)pWriteReq->data;
+    debug_log(std::string("uv_write() error:") + uv_strerror(r), LOG_INFO);
+    delete (std::shared_ptr<HttpResponse>*)pWriteReq->data;
     free(pWriteReq);
   } else {
     _pRequest->requestCompleted();
@@ -114,7 +118,7 @@ void HttpResponse::writeResponse() {
 
 void HttpResponse::onResponseWritten(int status) {
   ASSERT_BACKGROUND_THREAD()
-  trace("HttpResponse::onResponseWritten");
+  debug_log("HttpResponse::onResponseWritten", LOG_DEBUG);
   if (status != 0) {
     err_printf("Error writing response: %d\n", status);
     _closeAfterWritten = true; // Cause the request connection to close.
@@ -137,7 +141,7 @@ void HttpResponse::closeAfterWritten() {
 
 HttpResponse::~HttpResponse() {
   ASSERT_BACKGROUND_THREAD()
-  trace("HttpResponse::~HttpResponse");
+  debug_log("HttpResponse::~HttpResponse", LOG_DEBUG);
   if (_closeAfterWritten) {
     _pRequest->close();
   }
